summaryrefslogtreecommitdiff
path: root/src/html/html_mod_element.c
diff options
context:
space:
mode:
authorMichael Drake <michael.drake@codethink.co.uk>2016-01-28 14:14:34 +0000
committerMichael Drake <michael.drake@codethink.co.uk>2016-01-28 14:14:34 +0000
commitbab3f35ff01a5825034d23424b8e3866cb6376e7 (patch)
tree1cbd1b3bbd42cb5d06180783461edf89088f6853 /src/html/html_mod_element.c
parent809a7dcd1c803065eeb8ea39a605b6e0e2ec5241 (diff)
downloadlibdom-bab3f35ff01a5825034d23424b8e3866cb6376e7.tar.gz
libdom-bab3f35ff01a5825034d23424b8e3866cb6376e7.tar.bz2
Simplified consistant interface to HTMLElement creation.
Also fixes STYLE element not getting the correct namespace or prefix.
Diffstat (limited to 'src/html/html_mod_element.c')
-rw-r--r--src/html/html_mod_element.c25
1 files changed, 12 insertions, 13 deletions
diff --git a/src/html/html_mod_element.c b/src/html/html_mod_element.c
index 20f80d1..d952a1b 100644
--- a/src/html/html_mod_element.c
+++ b/src/html/html_mod_element.c
@@ -27,13 +27,13 @@ static struct dom_element_protected_vtable _protect_vtable = {
/**
* Create a dom_html_mod_element object
*
* \param doc The document object
* \param ele The returned element object
* \return DOM_NO_ERR on success, appropriate dom_exception on failure.
*/
-dom_exception _dom_html_mod_element_create(struct dom_html_document *doc,
- dom_string *tag_name, dom_string *namespace,
- dom_string *prefix, struct dom_html_mod_element **ele)
+dom_exception _dom_html_mod_element_create(
+ struct dom_html_element_create_params *params,
+ struct dom_html_mod_element **ele)
{
struct dom_node_internal *node;
@@ -46,22 +46,21 @@ dom_exception _dom_html_mod_element_create(struct dom_html_document *doc,
node->base.vtable = &_dom_html_element_vtable;
node->vtable = &_protect_vtable;
- return _dom_html_mod_element_initialise(doc, tag_name, namespace, prefix, *ele);
+ return _dom_html_mod_element_initialise(params, *ele);
}
/**
* Initialise a dom_html_mod_element object
*
* \param doc The document object
* \param ele The dom_html_mod_element object
* \return DOM_NO_ERR on success, appropriate dom_exception on failure.
*/
-dom_exception _dom_html_mod_element_initialise(struct dom_html_document *doc,
- dom_string *tag_name, dom_string *namespace,
- dom_string *prefix, struct dom_html_mod_element *ele)
+dom_exception _dom_html_mod_element_initialise(
+ struct dom_html_element_create_params *params,
+ struct dom_html_mod_element *ele)
{
- return _dom_html_element_initialise(doc, &ele->base,
- tag_name, namespace, prefix);
+ return _dom_html_element_initialise(params, &ele->base);
}
/**
@@ -27,13 +27,13 @@ static struct dom_element_protected_vtable _protect_vtable = {
* Create a dom_html_mod_element object
*
- * \param doc The document object
- * \param ele The returned element object
+ * \param params The html element creation parameters
+ * \param ele The returned element object
* \return DOM_NO_ERR on success, appropriate dom_exception on failure.
*/
@@ -46,22 +46,21 @@ dom_exception _dom_html_mod_element_create(struct dom_html_document *doc,
* Initialise a dom_html_mod_element object
*
- * \param doc The document object
- * \param ele The dom_html_mod_element object
+ * \param params The html element creation parameters
+ * \param ele The dom_html_mod_element object
* \return DOM_NO_ERR on success, appropriate dom_exception on failure.
*/